-- KorthiaRelics 1.0.7 by Hrazmadul
-- Created 2021-10-12
-- Updated 2022-02-23
-- 1.0.7 Updated TOC to 9.2
-- 1.0.6 Added quest checking for 75% archivist rep.
-- 1.0.5 Updated TOC to 9.1.5
-- 1.0.4 Added missing "Vault Emberstone" anima item.
-- 1.0.3 Added missing "Wafting Koricone" anima item. New Round() function to match Blizzard.
-- 1.0.2 Added counting of anima in the bags as 9.1.5 will allow you to turn in anima in Korthia.
-- 1.0.1 Oops forgot some changes I had made to my files.
-- 1.0.0 Trying out some stuff

local addonName
addonName = ...

local version="1.0.7"
local updated="2022-02-23"
local creator="Hrazmadul"

local f = CreateFrame("Frame");

local col_heirloom	= "cff00ccff"
local col_artifact	= "cffe6cc80"
local col_legendary	= "cffff8000"
local col_epic		= "cffa335ee"
local col_rare		= "cff0070dd"
local col_uncommon	= "cff1eff00"
local col_common	= "cffffffff"
local col_poor		= "cff9d9d9d"

local col_mogit		= "cffcc99ff"
local col_zonetext	= "cff8080ff"	-- cff8080ff purple
local col_title		= "cffffb200"	-- cffffb200 orange
local col_b		= "|"
local col_e		= "|r"

local col_v		= col_b..col_uncommon
local col_c		= col_b..col_mogit

local function ItemLink(color,id,idtext)
  linktext = "|"..color.."|Hitem:"..id.."::::::::120:::::|h["..idtext.."]|h|r"
return linktext
end

-- gives closest round by bad method 887/2 = 443
function round(number)
  return number - (number % 1)
end

local function round1(number, precision)
   local fmtStr = string.format('%%0.%sf',precision)
   number = string.format(fmtStr,number)
   return number
end

local function round2(num, numDecimalPlaces)
  local mult = 10^(numDecimalPlaces or 0)
  return math.floor(num * mult + 0.5) / mult
end

local function round3(exact, quantum)
    local quant,frac = math.modf(exact/quantum)
    return quantum * (quant + (frac > 0.5 and 1 or 0))
end

function round4(x)
  return x>=0 and math.floor(x+0.5) or math.ceil(x-0.5)
end

local function round5(num)
  return num + (2^52 + 2^51) - (2^52 + 2^51)
end

-- gives closest round by bad method 887/2 = 443
function round6(number)
  return number - (number % 1)
end

-------------------------------------------------------------------
-- Command line processing
-------------------------------------------------------------------

--  print(format("%s ("..col_b..col_zonetext.."%s"..col_e.."): %s%s",ItemLink(quests[i][5],quests[i][4],quests[i][1]), quests[i][2], qdone and "\124cff00ff00Yes\124r" or "\124cffff0000No\124r", tomtext))
-- /script local c = GetItemCount(65499) print("Conjured Mana Cake in inventory: ", c)
-- ItemLink(color,id,idtext)

-- relic fragments
-- https://www.wowhead.com/guides/archivists-codex-reputation-guide
-- worth 1
-- https://www.wowhead.com/item=186685/relic-fragment  -- worth 1

-- worth 8
-- https://www.wowhead.com/item=187322/crumbling-stone-tablet
-- https://www.wowhead.com/item=187457/engraved-glass-pane
-- https://www.wowhead.com/item=187324/gnawed-ancient-idol
-- https://www.wowhead.com/item=187323/runic-diagram
-- https://www.wowhead.com/item=187460/strangely-intricate-key
-- https://www.wowhead.com/item=187458/unearthed-teleporter-sigil
-- https://www.wowhead.com/item=187459/vial-of-mysterious-liquid

-- worth 48
-- https://www.wowhead.com/item=187465/complicated-organism-harmonizer
-- https://www.wowhead.com/item=187327/encrypted-korthian-journal
-- https://www.wowhead.com/item=187463/enigmatic-map-fragments
-- https://www.wowhead.com/item=187325/faded-razorwing-anatomy-illustration
-- https://www.wowhead.com/item=187326/half-completed-runeforge-pattern
-- https://www.wowhead.com/item=187462/scroll-of-shadowlands-fables
-- https://www.wowhead.com/item=187478/white-razorwing-talon

-- worth 100
-- https://www.wowhead.com/item=187336/forbidden-weapon-schematics
-- https://www.wowhead.com/item=187466/korthian-cypher-book
-- https://www.wowhead.com/item=187332/recovered-page-of-voices
-- https://www.wowhead.com/item=187328/ripped-cosmology-chart
-- https://www.wowhead.com/item=187334/shattered-void-tablet

-- worth 150
-- https://www.wowhead.com/item=187330/naaru-shard-fragment
-- https://www.wowhead.com/item=187329/old-god-specimen-jar
-- https://www.wowhead.com/item=187467/perplexing-rune-cube
-- https://www.wowhead.com/item=187331/tattered-fae-designs

-- worth 300
-- https://www.wowhead.com/item=187311/azgoths-tattered-maps
-- https://www.wowhead.com/item=187333/core-of-an-unknown-titan
-- https://www.wowhead.com/item=187350/displaced-relic
-- https://www.wowhead.com/item=187335/maldraxxus-larva-shell

-- https://www.wowhead.com/item=187136/research-report-relic-examination-techniques#comments
-- /run print(C_QuestLog.IsQuestFlaggedCompleted(64367))


local relic_ids = {
-- id, worth, name, color
{186685,1,"Relic Fragment",col_uncommon},

{187322,8,"Crumbling Stone Tablet",col_uncommon},
{187457,8,"Engraved Glass Pane",col_uncommon},
{187324,8,"Gnawed Ancient Idol",col_uncommon},
{187323,8,"Runic Diagram",col_uncommon},
{187460,8,"Strangely Intricate Key",col_uncommon},
{187458,8,"Unearthed Teleporter Sigil",col_uncommon},
{187459,8,"Vial of Mysterious Liquid",col_uncommon},

{187465,48,"Complicated Organism Harmonizer",col_rare},
{187327,48,"Encrypted Korthian Journal",col_rare},
{187463,48,"Enigmatic Map Fragments",col_rare},
{187325,48,"Faded Razorwing Anatomy Illustration",col_rare},
{187326,48,"Half-Completed Runeforge Pattern",col_rare},
{187462,48,"Scroll of Shadowlands Fables",col_rare},
{187478,48,"White Razorwing Talon",col_rare},

{187336,100,"Forbidden Weapon Schematics",col_epic},
{187466,100,"Korthian Cypher Book",col_epic},
{187332,100,"Recovered Page of Voices",col_epic},
{187328,100,"Ripped Cosmology Chart",col_epic},
{187334,100,"Shattered Void Tablet",col_epic},

{187330,150,"Naaru Shard Fragment",col_epic},
{187329,150,"Old God Specimen Jar",col_epic},
{187467,150,"Perplexing Rune-Cube",col_epic},
{187331,150,"Tattered Fae Designs",col_epic},

{187311,300,"Azgoth's Tattered Maps",col_epic},
{187333,300,"Core of an Unknown Titan",col_epic},
{187350,300,"Displaced Relic",col_epic},
{187335,300,"Maldraxxus Larva Shell",col_epic},
}

-- -----------------------------------------------------------------------
-- anima items
-- -----------------------------------------------------------------------
-- https://wowpedia.fandom.com/wiki/Category:Anima_items
-- ???? https://www.wowhead.com/item=183726/gratitude-of-the-liberated ??? exist?

-- worth 3
-- https://www.wowhead.com/item=183727/resonance-of-conflict
-- worth 5
-- https://www.wowhead.com/item=181540/animaflower-bud
-- https://www.wowhead.com/item=181544/confessions-of-misdeed
-- https://www.wowhead.com/item=181551/depleted-stoneborn-heart
-- https://www.wowhead.com/item=181642/novice-principles-of-plaguistry
-- https://www.wowhead.com/item=181643/weeping-corpseshroom
-- https://www.wowhead.com/item=181644/unlabeled-culture-jars
-- https://www.wowhead.com/item=181744/forgelite-ember
-- https://www.wowhead.com/item=184146/singed-soul-shackles
-- https://www.wowhead.com/item=184148/concealed-sinvyr-flask
-- https://www.wowhead.com/item=184151/counterfeit-ruby-brooch
-- https://www.wowhead.com/item=184152/bottle-of-diluted-anima-wine
-- https://www.wowhead.com/item=184293/sanctified-skylight-leaf
-- https://www.wowhead.com/item=184306/soulcatching-sludge
-- https://www.wowhead.com/item=184307/maldraxxi-armor-scraps
-- https://www.wowhead.com/item=184360/musings-on-repetition
-- https://www.wowhead.com/item=184373/small-anima-globe
-- https://www.wowhead.com/item=184385/fossilized-heartwood
-- https://www.wowhead.com/item=184386/nascent-sporepod
-- https://www.wowhead.com/item=184387/misty-shimmerleaf
-- https://www.wowhead.com/item=184388/plump-glitterroot
-- https://www.wowhead.com/item=184389/slumbering-starseed
-- https://www.wowhead.com/item=184769/pressed-torchlily-blossom
-- https://www.wowhead.com/item=184770/roster-of-the-forgotten
-- https://www.wowhead.com/item=184771/remembrance-parchment-ash
-- https://www.wowhead.com/item=186200/infused-dendrite
-- https://www.wowhead.com/item=186202/wafting-koricone  -- was missing in 1.0.2
-- https://www.wowhead.com/item=186203/glowing-devourer-stomach
-- https://www.wowhead.com/item=186204/anima-stained-glass-shards
-- worth 35
-- https://www.wowhead.com/item=181368/centurion-power-core
-- https://www.wowhead.com/item=181377/illustrated-combat-meditation-aid
-- https://www.wowhead.com/item=181477/ardendew-pearl
-- https://www.wowhead.com/item=181479/starlight-catcher
-- https://www.wowhead.com/item=181541/celestial-acorn
-- https://www.wowhead.com/item=181545/bloodbound-globule
-- https://www.wowhead.com/item=181546/mature-cryptbloom
-- https://www.wowhead.com/item=181547/nobles-draught
-- https://www.wowhead.com/item=181548/darkhaven-soul-lantern
-- https://www.wowhead.com/item=181550/hopebreakers-field-injector
-- https://www.wowhead.com/item=181645/engorged-monstrositys-heart
-- https://www.wowhead.com/item=181647/stabilized-plague-strain
-- https://www.wowhead.com/item=181649/preserved-preternatural-braincase
-- https://www.wowhead.com/item=181745/forgesmiths-coal
-- https://www.wowhead.com/item=184147/agony-enrichment-device
-- https://www.wowhead.com/item=184150/bonded-tallow-candles
-- https://www.wowhead.com/item=184286/extinguished-soul-anima
-- https://www.wowhead.com/item=184294/ethereal-ambrosia
-- https://www.wowhead.com/item=184305/maldraxxi-champions-armaments
-- https://www.wowhead.com/item=184362/reflections-on-purity
-- https://www.wowhead.com/item=184363/considerations-on-courage
-- https://www.wowhead.com/item=184371/vivacity-of-collaboration
-- https://www.wowhead.com/item=184374/cartel-exchange-vessel
-- https://www.wowhead.com/item=184378/faeweald-amber
-- https://www.wowhead.com/item=184381/astral-sapwood
-- https://www.wowhead.com/item=184382/luminous-sylberry
-- https://www.wowhead.com/item=184383/duskfall-tuber
-- https://www.wowhead.com/item=184384/hibernal-sproutling
-- https://www.wowhead.com/item=184519/totem-of-stolen-mojo
-- https://www.wowhead.com/item=184765/vesper-strikehammer
-- https://www.wowhead.com/item=184766/chronicles-of-the-paragons
-- https://www.wowhead.com/item=184767/handheld-soul-mirror
-- https://www.wowhead.com/item=184768/censer-of-dried-gracepetals
-- https://www.wowhead.com/item=184772/ritual-maldracite-crystal
-- https://www.wowhead.com/item=184773/battle-tested-armor-component
-- https://www.wowhead.com/item=184774/juvenile-sporespindle
-- https://www.wowhead.com/item=184775/necromancy-for-the-practical-ritualist
-- https://www.wowhead.com/item=184776/urn-of-arena-soil
-- https://www.wowhead.com/item=184777/gravedredgers-shovel
-- https://www.wowhead.com/item=186201/ancient-anima-vessel
-- https://www.wowhead.com/item=186205/scholarly-attendants-bangle
-- https://www.wowhead.com/item=186206/vault-emberstone -- missing in 1.0.3
-- https://www.wowhead.com/item=187432/magifocus-heartwood
-- https://www.wowhead.com/item=187433/windcrystal-chimes
-- https://www.wowhead.com/item=187434/lightseed-sapling
-- worth 250
-- https://ptr.wowhead.com/item=188000/grovetenders-pack ??? exist?
-- https://ptr.wowhead.com/item=188003/crate-of-revendreth-reserve ??? exist?
-- https://ptr.wowhead.com/item=188004/crate-of-anima-infused-parts ??? exist?
-- https://ptr.wowhead.com/item=188005/anima-bathed-blade ??? exist?
-- https://www.wowhead.com/item=181478/cornucopia-of-the-winter-court
-- https://www.wowhead.com/item=181549/timeworn-sinstone
-- https://www.wowhead.com/item=181552/collected-tithe
-- https://www.wowhead.com/item=181646/bound-failsafe-phylactery
-- https://www.wowhead.com/item=181648/ziggurat-focusing-crystal
-- https://www.wowhead.com/item=181650/spellwarded-dissertation
-- https://www.wowhead.com/item=181743/plume-of-the-archon
-- https://www.wowhead.com/item=183723/brimming-anima-orb
-- https://www.wowhead.com/item=184149/widowbloom-infused-fragrance
-- https://www.wowhead.com/item=184315/multi-modal-anima-container
-- https://www.wowhead.com/item=184379/queens-frozen-tear
-- https://www.wowhead.com/item=184380/starblossom-nectar
-- https://www.wowhead.com/item=184763/mnemis-neural-network
-- https://www.wowhead.com/item=184764/colossus-actuator
-- https://www.wowhead.com/item=187175/runekeepers-ingot
-- https://www.wowhead.com/item=187347/concentrated-anima
-- https://www.wowhead.com/item=187349/anima-laden-egg one time item?
-- https://www.wowhead.com/item=187517/animaswell-prism



local anima_ids = {
-- id, worth, name, color
-- worth 3
{183727,3,"Resonance of Conflict",col_uncommon},
-- worth 5
{181540,5,"Animaflower Bud",col_uncommon},
{181544,5,"Confessions of Misdeed",col_uncommon},
{181551,5,"Depleted Stoneborn Heart",col_uncommon},
{181642,5,"Novice Principles of Plaguistry",col_uncommon},
{181643,5,"Weeping Corpseshroom",col_uncommon},
{181644,5,"Unlabeled Culture Jars",col_uncommon},
{181744,5,"Forgelite Ember",col_uncommon},
{184146,5,"Singed Soul Shackles",col_uncommon},
{184148,5,"Concealed Sinvyr Flask",col_uncommon},
{184151,5,"Counterfeit Ruby Brooch",col_uncommon},
{184152,5,"Bottle of Diluted Anima-Wine",col_uncommon},
{184293,5,"Sanctified Skylight Leaf",col_uncommon},
{184306,5,"Soulcatching Sludge",col_uncommon},
{184307,5,"Maldraxxi Armor Scraps",col_uncommon},
{184360,5,"Musings on Repetition",col_uncommon},
{184373,5,"Small Anima Globe",col_uncommon},
{184385,5,"Fossilized Heartwood",col_uncommon},
{184386,5,"Nascent Sporepod",col_uncommon},
{184387,5,"Misty Shimmerleaf",col_uncommon},
{184388,5,"Plump Glitterroot",col_uncommon},
{184389,5,"Slumbering Starseed",col_uncommon},
{184769,5,"Pressed Torchlily Blossom",col_uncommon},
{184770,5,"Roster of the Forgotten",col_uncommon},
{184771,5,"Remembrance Parchment Ash",col_uncommon},
{186200,5,"Infused Dendrite",col_uncommon},
{186202,5,"Wafting Koricone",col_uncommon}, -- was missing in 1.0.2
{186203,5,"Glowing Devourer Stomach",col_uncommon},
{186204,5,"Anima-Stained Glass Shards",col_uncommon},
-- worth 35
{181368,35,"Centurion Power Core",col_rare},
{181377,35,"Illustrated Combat Meditation Aid",col_rare},
{181477,35,"Ardendew Pearl",col_rare},
{181479,35,"Starlight Catcher",col_rare},
{181541,35,"Celestial Acorn",col_rare},
{181545,35,"Bloodbound Globule",col_rare},
{181546,35,"Mature Cryptbloom",col_rare},
{181547,35,"Nobles Draught",col_rare},
{181548,35,"Darkhaven Soul Lantern",col_rare},
{181550,35,"Hopebreaker's Field Injector",col_rare},
{181645,35,"Engorged Monstrosity's Heart",col_rare},
{181647,35,"Stabilized Plague Strain",col_rare},
{181649,35,"Preserved Preternatural Braincase",col_rare},
{181745,35,"Forgesmith's Coal",col_rare},
{184147,35,"Agony Enrichment Device",col_rare},
{184150,35,"Bonded Tallow Candles",col_rare},
{184286,35,"Extinguished Soul Anima",col_rare},
{184294,35,"Ethereal Ambrosia",col_rare},
{184305,35,"Maldraxxi Champion's Armaments",col_rare},
{184362,35,"Reflections on Purity",col_rare},
{184363,35,"Considerations on Courage",col_rare},
{184371,35,"Vivacity of Collaboration",col_rare},
{184374,35,"Cartel Exchange Vessel",col_rare},
{184378,35,"Faeweald Amber",col_rare},
{184381,35,"Astral Sapwood",col_rare},
{184382,35,"Luminous Sylberry",col_rare},
{184383,35,"Duskfall Tuber",col_rare},
{184384,35,"Hibernal Sproutling",col_rare},
{184519,35,"Totem of Stolen Mojo",col_rare},
{184765,35,"Vesper Strikehammer",col_rare},
{184766,35,"Chronicles of the Paragons",col_rare},
{184767,35,"Handheld Soul Mirror",col_rare},
{184768,35,"Censer of Dried Gracepetals",col_rare},
{184772,35,"Ritual Maldracite Crystal",col_rare},
{184773,35,"Battle Tested Armor Component",col_rare},
{184774,35,"Juvenile Sporespindle",col_rare},
{184775,35,"Necromancy for the Practical Ritualist",col_rare},
{184776,35,"Urn of Arena Soil",col_rare},
{184777,35,"Gravedredger's Shovel",col_rare},
{186201,35,"Ancient Anima Vessel",col_rare},
{186205,35,"Scholarly Attendant's Bangle",col_rare},
{186206,35,"Vault Emberstone",col_rare}, -- missing in 1.0.3
{187432,35,"Magifocus Heartwood",col_rare},
{187433,35,"Windcrystal Chimes",col_rare},
{187434,35,"Lightseed Sapling",col_rare},
-- worth 250
{188000,250,"Grovetender's Pack",col_epic}, -- ??? exist?
{188003,250,"Crate of Revendreth Reserve",col_epic}, -- ??? exist?
{188004,250,"Crate of Anima-Infused Parts",col_epic}, -- ??? exist?
{188005,250,"Anima-Bathed Blade",col_epic}, -- ??? exist?
{181478,250,"Cornucopia of the Winter Court",col_epic},
{181549,250,"Timeworn Sinstone",col_epic},
{181552,250,"Collected Tithe",col_epic},
{181646,250,"Bound Failsafe Phylactery",col_epic},
{181648,250,"Ziggurat Focusing Crystal",col_epic},
{181650,250,"Spellwarded Dissertation",col_epic},
{181743,250,"Plume of the Archon",col_epic},
{183723,250,"Brimming Anima Orb",col_epic},
{184149,250,"Widowbloom-Infused Fragrance",col_epic},
{184315,250,"Multi-Modal Anima Container",col_epic},
{184379,250,"Queens Frozen Tear",col_epic},
{184380,250,"Starblossom Nectar",col_epic},
{184763,250,"Mnemis Neural-Network",col_epic},
{184764,250,"Colossus Actuator",col_epic},
{187175,250,"Runekeeper's Ingot",col_epic},
{187347,250,"Concentrated Anima",col_epic},
{187349,250,"Anima-Laden Egg",col_epic}, -- one time item?
{187517,250,"Animaswell Prism",col_epic},
}

SLASH_RELICS1 = "/relics"
SlashCmdList["RELICS"] = function(args)
  local cmd, arg = strsplit(" ",args,2)
  local printall = false
  local printall2 = false
  cmd = cmd:lower()

  if cmd == "list" then
     printall=true
  end

  if cmd == "list-anima" then
     printall2=true
  end


  print("KorthiaRelics Summarize "..col_v..version..col_e.." by "..col_c..creator..col_e.." - updated "..updated)

  local relicsum = 0
  local reliccount = 0
  local tempsum = 0
  local doprint = false

  for i=1,table.getn(relic_ids) do
    reliccount = GetItemCount(relic_ids[i][1])
    tempsum = reliccount * relic_ids[i][2]
    relicsum = relicsum + tempsum

    if printall == true then doprint = true
    elseif reliccount > 0 then doprint = true
    else doprint = false
    end

    if doprint == true then
      print(format("%s w:%s c:%s s:%s",ItemLink(relic_ids[i][4],relic_ids[i][1],relic_ids[i][3]),relic_ids[i][2],reliccount,tempsum))
    end --if
  end --for

  -- print(format("Total Relic Research Sum: %s",relicsum))

  print(format("Korthian Relic Research Sum: %s",relicsum))
  -- print(format("The Archivists Codex Rep (halved): %s",tostring(round(relicsum/2,0))))

  -- print(format("Quest for 75%% turnin: %s", tostring(C_QuestLog.IsQuestFlaggedCompleted(64367))))

  if C_QuestLog.IsQuestFlaggedCompleted(64367) then
    print(format("The Archivists Codex Rep (75%%): %s",tostring(round(relicsum*0.75))))
  else
    print(format("The Archivists Codex Rep (50%%): %s",tostring(round(relicsum/2))))
  end -- else

  -- since 9.1.5 will allow you to store anima in krothia I found it prudent to also count these.

  local animasum = 0
  local animacount = 0
  for i=1,table.getn(anima_ids) do
    animacount = GetItemCount(anima_ids[i][1])
    tempsum = animacount * anima_ids[i][2]
    animasum = animasum + tempsum

    if printall2 == true then doprint = true
    elseif animacount > 0 then doprint = true
    else doprint = false
    end

    if doprint == true then
      print(format("%s w:%s c:%s s:%s",ItemLink(anima_ids[i][4],anima_ids[i][1],anima_ids[i][3]),anima_ids[i][2],animacount,tempsum))
    end --if
  end --for

  print(format("Anima in bags: %s",tostring(animasum)))
  -- round(887/2) should yield 443 apparently
  -- print(round(887/2,0))
  -- print(round2(887/2,0))
  -- print(round3(887/2,0))
  -- print(round4(887/2))
  -- print(round5(887/2))
  -- print(round6(887/2))
end

function KorthiaRelics_OnEvent(frame, event, name, ...)
end

f:SetScript("OnEvent", KorthiaRelics_OnEvent);
f:RegisterEvent("ADDON_LOADED")
